@@ -1,4 +1,8 @@
 #' Modelling superannuation changes
+#' 
+#' @description Model changes to the contributions cap, Division 293 threshold 
+#' and related modelling. Note: defaults are relevant to pre-2017 for 
+#' compatibility.
 
 
 #' @param .sample.file A \code{data.table} whose variables include those in \code{taxstats::sample_file_1314}.
@@ -8,6 +12,7 @@
 #' @param new_age_based_cap Is the \strong{proposed} cap on concessional contributions age-based? 
 #' @param new_cap2_age The age above which \code{new_cap2} applies.
 #' @param new_ecc (logical) Should an excess concessional contributions charge be calculated? (Not implemented.)
+#' @param new_contr_tax A string to determine the contributions tax.
 #' @param new_div293_threshold The \strong{proposed} Division 293 threshold. 
 #' @param use_other_contr Should \code{MCS_Othr_Contr} be used to calculate Division 293 liabilities?
 #' @param scale_contr_match_ato (logical) Should concessional contributions be inflated to match aggregates in 2013-14? That is, should the concessional contributions by multiplied by the internal constant \code{grattan:::super_contribution_inflator_1314}, which was defined to be: \deqn{\frac{\textrm{Total assessable contributions in SMSF and funds}}{\textrm{Total contributions in 2013-14 sample file}}}{Total assessable contributions in SMSF and funds / Total contributions in 2013-14 sample file.}. 
@@ -25,7 +30,23 @@
 #' @param prv_div293_threshold The \strong{comparator} Division 293 threshold. 
 #' @param ... Passed to \code{model_new_caps_and_div293}.
 #' @param adverse_only Count only individuals who are adversely affected by the change.
-#' @return For \code{model_new_caps_and_div293}, A data.frame, comprising \code{.sample.file}, the superannuation variables generated by \code{apply_super_caps_and_div293}, and two variables \code{prv_revenue} and \code{new_revenue} which give the tax (income tax, super tax, and division 293 tax) payable by that taxpayer in the comparator scenario and the proposed scenario, respectively.
+#' @return For \code{model_new_caps_and_div293}, a \code{data.frame}, comprising 
+#' the variables in \code{.sample.file}, the superannuation variables generated by 
+#' \code{apply_super_caps_and_div293}, and two variables, \code{prv_revenue} and \code{new_revenue},
+#'  which give the tax (income tax, super tax, and division 293 tax) payable by 
+#'  that taxpayer in the comparator scenario and the proposed scenario, respectively.
+#' 
+#' @examples
+#' 
+#' if (requireNamespace("taxstats", quietly = TRUE)) {
+#'   library(data.table)
+#'   s1314 <- taxstats::sample_file_1314
+#'   s1314[, WEIGHT := 50L]
+#'   revenue_from_new_cap_and_div293(s1314, new_cap = 12e3, "2016-17")
+#'   revenue_from_new_cap_and_div293(s1314, new_contr_tax = "mr - 15%", "2016-17")
+#' }
+#' 
+#' 
 #' @export
 
 model_new_caps_and_div293 <- function(.sample.file, 
@@ -35,8 +56,8 @@ model_new_caps_and_div293 <- function(.sample.file,
                                       new_age_based_cap = TRUE, 
                                       new_cap2_age = 49, 
                                       new_ecc = FALSE,
+                                      new_contr_tax = "15%",
                                       new_div293_threshold = 300e3,
-                                      
                                       use_other_contr = FALSE, 
                                       scale_contr_match_ato = FALSE, 
                                       .lambda = 0, 
@@ -51,7 +72,7 @@ model_new_caps_and_div293 <- function(.sample.file,
                                       prv_age_based_cap = TRUE, 
                                       prv_cap2_age = 49, 
                                       prv_ecc = FALSE,
-                                      prv_div293_threshold = 300e3){
+                                      prv_div293_threshold = 300e3) {
   prv_revenue <- new_revenue <- NULL
   if (!any("WEIGHT" == names(.sample.file))){
     warning("WEIGHT not specified. Using WEIGHT=50 (assuming a 2% sample file).")
@@ -59,6 +80,8 @@ model_new_caps_and_div293 <- function(.sample.file,
     .sample.file[, WEIGHT := WEIGHT]
   } 
   
+  
+  
   sample_file <- apply_super_caps_and_div293(.sample.file, 
                                              colname_concessional = "old_concessional_contributions",
                                              colname_div293_tax = "old_div293_tax", 
@@ -88,12 +111,17 @@ model_new_caps_and_div293 <- function(.sample.file,
   old_div293_tax <- NULL
   new_div293_tax <- NULL
   
-  sample_file[, prv_revenue := income_tax(old_Taxable_Income, fy.year) + old_div293_tax]
-  sample_file <- sample_file[, c("Ind", "prv_revenue", "old_concessional_contributions", "old_div293_tax", "div293_income"), with = FALSE]
+  sample_file <- 
+    sample_file[, c("Ind", "old_concessional_contributions", "old_div293_tax", 
+                    "div293_income", "old_Taxable_Income"),
+                with = FALSE]
   sample_file %>%
     setnames("div293_income", "old_div293_income") %>%
     setkeyv("Ind")
   
+  
+  
+  
   new_sample_file <- apply_super_caps_and_div293(.sample.file, 
                                                  colname_concessional = "new_concessional_contributions",
                                                  colname_div293_tax = "new_div293_tax", 
@@ -118,9 +146,50 @@ model_new_caps_and_div293 <- function(.sample.file,
                                                  drop_helpers = FALSE, 
                                                  copyDT = TRUE)
   
-  new_sample_file[, new_revenue := income_tax(new_Taxable_Income, fy.year) + new_div293_tax]
+  
+  sexp_contributions_tax <- substitute(new_contr_tax)
+  use_marginal_rate <- 
+    !missing(new_contr_tax) &&
+    length(new_contr_tax) == 1L &&
+    is.character(new_contr_tax) &&
+    startsWith(new_contr_tax, "mr")
+  
+  rel_marginal_rate <- 0
+  if (use_marginal_rate) {
+    if (startsWith(new_contr_tax, "mr - ")) {
+      rel_marginal_rate <- -as.double(sub("^mr - ([0-9]+)[%]$", "\\1", new_contr_tax)) / 100
+    } else if (startsWith(new_contr_tax, "mr + ")) {
+      rel_marginal_rate <- +as.double(sub("^mr . ([0-9]+)[%]$", "\\1", new_contr_tax)) / 100
+    } else {
+      stop("`contributions_tax = ", new_contr_tax, "` ", 
+           "not of the form mr - <double> or mr + <double>")
+    }
+  }
+  
+  
+  
+  
   setkeyv(new_sample_file, "Ind")
-  sample_file[new_sample_file]
+  ans <- sample_file[new_sample_file]
+  
+  ans[, OldContributionsTax := 0.15 * old_concessional_contributions]
+  prv_ordinary_tax <- NULL
+  ans[, prv_ordinary_tax := income_tax(old_Taxable_Income, fy.year, .dots.ATO = .SD)]
+  ans[, prv_revenue := income_tax(old_Taxable_Income, fy.year, .dots.ATO = .SD) + old_div293_tax + OldContributionsTax]
+  if (use_marginal_rate) {
+    NewMarginalRate <- OldContributionsTax <- NewContributionsTax <-
+      old_concessional_contributions <- new_concessional_contributions <- NULL
+    
+    ans[, NewMarginalRate := marginal_rate(new_sample_file, fy.year)]
+    ans[, NewContributionsTax := (NewMarginalRate + rel_marginal_rate) * new_concessional_contributions]
+   
+  } else {
+    ans[, NewContributionsTax := 0.15 * new_concessional_contributions]
+  }
+  ans[, new_ordinary_tax := income_tax(new_Taxable_Income, fy.year, .dots.ATO = .SD)]
+  new_ordinary_tax <- NULL
+  ans[, new_revenue := income_tax(new_Taxable_Income, fy.year, .dots.ATO = .SD) + NewContributionsTax + new_div293_tax]
+  ans
 }
 
 #' @rdname model_new_caps_and_div293
